==> haskell-tls-session-manager-0.0.5-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tls-session-manager
version:              0.0.5
visibility:           public
id:                   tls-session-manager-0.0.5-8EV07makF5N7NNSb6QxdFi
key:                  tls-session-manager-0.0.5-8EV07makF5N7NNSb6QxdFi
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             In-memory TLS session DB and session ticket
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance and session ticket manager

category:             Web
abi:                  a49744c456bf39efae343dc9d46eae86
exposed:              True
exposed-modules:      Network.TLS.SessionManager Network.TLS.SessionTicket
hidden-modules:       Network.TLS.Imports
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tls-session-manager
hs-libraries:         HStls-session-manager-0.0.5-8EV07makF5N7NNSb6QxdFi
depends:
    auto-update-0.1.6-ImzSmIgtqtK5NclgP8vMHq base-4.17.2.1
    basement-0.0.16-6gl6nPF7HiTCe5hoNBpAx7 bytestring-0.11.5.3
    clock-0.8.4-LqToM72vVsXFDj6aYtb09g
    crypto-token-0.1.1-E4o94r8pcYhI6V2Zw1u53v
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    psqueues-0.2.8.1-DHUA0hD1tsJgNbV5mf4OB
    serialise-0.2.6.1-LGLO7J4YZ3PJ7o2n9Tj4dH
    tls-2.0.6-73zz57YvMDyLHFcPlOnKYG

haddock-interfaces:
    /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock

haddock-html:         /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-session-manager-0.0.5-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tls-session-manager
version:              0.0.5
visibility:           public
id:                   tls-session-manager-0.0.5-4oOscwmlvTSFLdqGpHr38b
key:                  tls-session-manager-0.0.5-4oOscwmlvTSFLdqGpHr38b
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             In-memory TLS session DB and session ticket
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance and session ticket manager

category:             Web
abi:                  50e071bd214969c6df5506f10c2e61eb
exposed:              True
exposed-modules:      Network.TLS.SessionManager Network.TLS.SessionTicket
hidden-modules:       Network.TLS.Imports
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tls-session-manager-0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tls-session-manager
hs-libraries:         HStls-session-manager-0.0.5-4oOscwmlvTSFLdqGpHr38b
depends:
    auto-update-0.1.6-TVuXptZc6BKI0rZZ7cvie base-4.17.2.1
    basement-0.0.16-6gl6nPF7HiTCe5hoNBpAx7 bytestring-0.11.5.3
    clock-0.8.4-4Tm2YAbccBDGCqjcUDyDfy
    crypto-token-0.1.1-3ay3rWa72zCEtinQwGg6sq
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    psqueues-0.2.8.1-2snP1VXSxdwJdHDhtKmpIH
    serialise-0.2.6.1-AqTCj3f6AF04df2xlUlNSP
    tls-2.0.6-GY5G8XI1HyTF5N72nDY5h6

haddock-interfaces:
    /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock

haddock-html:         /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
